@@ -13,6 +13,7 @@ BY_BIRTH = "BY_BIRTH"
 CANCELLED = "cancelled"
 CHOL = "chol"
 CLOSED = "closed"
+COLLATERAL_HISTORY = "collateral_history"
 COMPLETE = "COMPLETE"
 CONSENTED = "consented"
 CONTINUOUS = "continuous"
@@ -38,10 +39,10 @@ FEEDBACK = "feedback"
 FEMALE = "F"
 FORMER_SMOKER = "former_smoker"
 FREE_OF_CHARGE = "free"
+HEADACHE = "headache"
 HELD = "held"
 HIDE_FORM = "NOT_REQUIRED"
 HIGH = "high"
-HIGH = "high"
 HIGH_PRIORITY = "high"
 HIV = "HIV"
 HOSPITALIZED = "hospitalized"
@@ -54,6 +55,7 @@ IND = "IND"
 INITIAL = "initial"
 INSERT = "INSERT"
 INTERVENTION = "intervention"
+IN_PERSON = "in_person"
 LOW = "low"
 LOW_PRIORITY = "low"
 MALE = "M"
@@ -68,6 +70,7 @@ NEG = "NEG"
 NEVER = "NEVER"
 NEW = "New"
 NEW_FIELD = "new_field"
+NEXT_OF_KIN = "next_of_kin"
 NO = "No"
 NONE = "none"
 NONSMOKER = "nonsmoker"
@@ -96,9 +99,12 @@ OPEN = "open"
 OPTIONAL = True
 OTHER = "OTHER"
 OTHER_PLEASE_SPECIFY_TEXT = "Other, please specify below ..."
+OUTPATIENT_CARDS = "outpatient_cards"
 PARTIAL = "PARTIAL"
 PARTICIPANT = "participant"
 PATIENT = "patient"
+PATIENT = "patient"
+PATIENT_REPRESENTATIVE = "patient_representative"
 PENDING = "PENDING"
 POS = "POS"
 PRESENT = "present"
@@ -127,6 +133,7 @@ STUDY_DEFINED_TIMEPOINT = "study_defined_timepoint"
 SUBJECT = "subject"
 SYSTEMATIC = "systematic"
 TBD = "tbd"  # to be determined
+TELEPHONE = "telephone"
 TERTIARY = "tertiary"
 TRUE = "true"
 TUBERCULOSIS = "TB"
@@ -138,6 +145,7 @@ UUID_PATTERN = re.compile(
     "[a-f0-9]{8}-?[a-f0-9]{4}-?4[a-f0-9]{3}-?[89ab][a-f0-9]{3}-?[a-f0-9]{12}"
 )
 VIEW = "VIEW"
+VISUAL_LOSS = "visual_loss"
 WARN = "warn"
 WEEKDAYS = "weekdays"
 WEEKENDS = "weekends"
